@@ -2,6 +2,7 @@ import re
 
 from pythonbible.regular_expressions import BOOK_REGULAR_EXPRESSIONS
 from pythonbible.regular_expressions import SCRIPTURE_REFERENCE_REGULAR_EXPRESSION
+from pythonbible.roman_numeral_util import convert_all_roman_numerals_to_integers
 from pythonbible.validator import is_valid_reference
 from pythonbible.verses import get_max_number_of_verses
 
@@ -9,12 +10,16 @@ from pythonbible.verses import get_max_number_of_verses
 def get_references(text):
     """
     Searches the text for scripture references and returns any that are found in a list of normalized tuple references.
+
     :param text: a string that may contain zero or more scripture references
     :return: a list of tuples. each tuple is in the format (book, start_chapter, start_verse, end_chapter, end_verse)
     """
     references = []
 
-    for match in re.finditer(SCRIPTURE_REFERENCE_REGULAR_EXPRESSION, text):
+    # First replace all roman numerals in the text with integers.
+    clean_text = convert_all_roman_numerals_to_integers(text)
+
+    for match in re.finditer(SCRIPTURE_REFERENCE_REGULAR_EXPRESSION, clean_text):
         references.extend(normalize_reference(match[0]))
 
     return references
@@ -23,6 +28,7 @@ def get_references(text):
 def normalize_reference(reference):
     """
     Converts a scripture reference string into a list of normalized tuple references.
+
     :param reference: a string that is a scripture reference
     :return: a list of tuples. each tuple is in the format (book, start_chapter, start_verse, end_chapter, end_verse)
     """
@@ -62,7 +68,8 @@ def _process_sub_reference(sub_reference, book, start_chapter):
     end_verse = None
     no_verses = False
 
-    chapter_and_verse_range = sub_reference.split("-")
+    clean_sub_reference = sub_reference.replace(".", ":")
+    chapter_and_verse_range = clean_sub_reference.split("-")
     min_chapter_and_verse = chapter_and_verse_range[0]
     min_chapter_and_verse = min_chapter_and_verse.split(":")
 
